@@ -4,17 +4,17 @@
 modname = "cubicweb_varnish"
 distname = "cubicweb-varnish"
 
-numversion = (0, 8, 0)
+numversion = (1, 0, 0)
 version = ".".join(str(num) for num in numversion)
 
 license = "LGPL-2.1"
 author = "LOGILAB S.A. (Paris, FRANCE)"
 author_email = "contact@logilab.fr"
 description = "cubicweb varnish helper"
-web = "https://forge.extranet.logilab.fr/cubicweb/cubes/%s" % distname
+web = f"https://forge.extranet.logilab.fr/cubicweb/cubes/{distname}"
 
 __depends__ = {
-    "cubicweb": ">= 3.31.0, < 3.39.0",
+    "cubicweb": ">= 3.31.0, < 5.0.0",
 }
 __recommends__ = {}
 
