@@ -21,7 +21,7 @@ from cubicweb.entity import EntityAdapter
 
 class IVarnishAdapter(EntityAdapter):
     __abstract__ = True
-    __regid__ = 'IVarnish'
+    __regid__ = "IVarnish"
 
     def urls_to_purge(self):
         return ()
