@@ -55,10 +55,10 @@ class InvalidateVarnishCacheOp(hook.DataOperationMixIn, hook.Operation):
         elif varnish_version >= 4:
             purge_cmd = "ban req.url ~"
         else:
-            raise ValueError("Unsupported varnish version %s" % varnish_version)
+            raise ValueError(f"Unsupported varnish version {varnish_version}")
         cnxs = varnish_cli_connect_from_config(config)
         for url in self.get_data():
             for varnish_cli in cnxs:
-                varnish_cli.execute(purge_cmd, "^%s$" % urlparse(url).path)
+                varnish_cli.execute(purge_cmd, f"^{urlparse(url).path}$")
         for varnish_cli in cnxs:
             varnish_cli.close()
