@@ -99,7 +99,7 @@ class VarnishCLI:
         return int(code), msg
 
     def _send(self, instruction):
-        self._wfile.write("%s\n" % instruction)
+        self._wfile.write(f"{instruction}\n")
         self._wfile.flush()
         return self._receive()
 
